@@ -2,8 +2,8 @@
 
 ;; Author: jixiuf  jixiuf@qq.com
 ;; Keywords: vterm terminals
-;; Package-Version: 20260105.1117
-;; Package-Revision: 0c2935945659
+;; Package-Version: 20260110.529
+;; Package-Revision: 81d031f153c5
 ;; URL: https://github.com/jixiuf/vterm-toggle
 ;; Package-Requires: ((emacs "25.1") (vterm "0.0.1"))
 
@@ -438,7 +438,8 @@ Optional argument ARGS optional args."
 
 (defun vterm-toggle--mode-hook()
   "Hook for `vterm-mode-hook'."
-  (add-to-list 'vterm-toggle--buffer-list (current-buffer)))
+  (when (vterm-toggle-togglable-buffer-p (current-buffer))
+    (add-to-list 'vterm-toggle--buffer-list (current-buffer))))
 (add-hook 'vterm-mode-hook #'vterm-toggle--mode-hook)
 
 (dolist (buf (buffer-list))
